@@ -1,52 +1,52 @@
 #' Simonoff-Tsai Tests for Heteroskedasticity in a Linear Regression Model
 #'
 #' This function implements the modified profile likelihood ratio test and
-#'   score test of \insertCite{Simonoff94;textual}{skedastic} for testing
-#'   for heteroskedasticity in a linear regression model.
+#'    score test of \insertCite{Simonoff94;textual}{skedastic} for testing
+#'    for heteroskedasticity in a linear regression model.
 #'
-#' The Simonoff-Tsai Likelihood Ratio Test involves a modification of the
-#' profile likelihood function so that the nuisance parameter will be
-#' orthogonal to the parameter of interest. The maximum likelihood estimate
-#' of \eqn{\lambda} (called \eqn{\delta} in
-#' \insertCite{Simonoff94;textual}{skedastic}) is computed from the modified
-#' profile log-likelihood function using the Nelder-Mead algorithm in
-#' \code{\link[stats]{optim}}. Under the null hypothesis of homoskedasticity,
-#' the distribution of the test statistic is asymptotically chi-squared with
-#' \eqn{q} degrees of freedom. The test is right-tailed.
+#' @details The Simonoff-Tsai Likelihood Ratio Test involves a modification of
+#'    the profile likelihood function so that the nuisance parameter will be
+#'    orthogonal to the parameter of interest. The maximum likelihood estimate
+#'    of \eqn{\lambda} (called \eqn{\delta} in
+#'    \insertCite{Simonoff94;textual}{skedastic}) is computed from the modified
+#'    profile log-likelihood function using the Nelder-Mead algorithm in
+#'    \code{\link[stats]{optim}}. Under the null hypothesis of
+#'    homoskedasticity, the distribution of the test statistic is
+#'    asymptotically chi-squared with \eqn{q} degrees of freedom. The test is
+#'    right-tailed.
 #'
 #' The Simonoff-Tsai Score Test entails adding a term to either the score
-#' statistic of \insertCite{Cook83;textual}{skedastic} (a test implemented in
-#' \code{\link{cook_weisberg}}) or to that of
-#' \insertCite{Koenker81;textual}{skedastic} (a test implemented in
-#' \code{\link{breusch_pagan}} with argument \code{koenker} set to
-#' \code{TRUE}), in order to improve the robustness of these respective tests
-#' in the presence of non-normality. This test likewise has a test statistic
-#' that is asymptotically \eqn{\chi^2(q)}-distributed and the test is likewise
-#' right-tailed.
+#'    statistic of \insertCite{Cook83;textual}{skedastic} (a test implemented
+#'    in \code{\link{cook_weisberg}}) or to that of
+#'    \insertCite{Koenker81;textual}{skedastic} (a test implemented in
+#'    \code{\link{breusch_pagan}} with argument \code{koenker} set to
+#'    \code{TRUE}), in order to improve the robustness of these respective
+#'    tests in the presence of non-normality. This test likewise has a test
+#'    statistic that is asymptotically \eqn{\chi^2(q)}-distributed and the test
+#'    is likewise right-tailed.
 #'
 #' The assumption of underlying both tests is that
-#' \eqn{\mathrm{Cov}(\epsilon)=\sigma^2 W}, where \eqn{W} is
-#' an \eqn{n\times n} diagonal matrix with \eqn{i}th diagonal element
-#' \eqn{w_i=w(Z_i, \lambda)}. Here, \eqn{Z_i} is the \eqn{i}th row of an
-#' \eqn{n \times q} nonstochastic auxiliary design matrix \eqn{Z}. Note:
-#' \eqn{Z} as defined here does not have a column of ones, but is concatenated
-#' to a column of ones when used in an auxiliary regression.
-#' \eqn{\lambda} is a \eqn{q}-vector of unknown parameters, and \eqn{w(\cdot)}
-#' is a real-valued, twice-differentiable function having the property that
-#' there exists some \eqn{\lambda_0} for which
-#' \eqn{w(Z_i,\lambda_0)=0} for all \eqn{i=1,2,\ldots,n}. Thus, the null
-#' hypothesis of homoskedasticity may be expressed as
-#' \eqn{\lambda=\lambda_0}.
+#'    \eqn{\mathrm{Cov}(\epsilon)=\omega W}, where \eqn{W} is
+#'    an \eqn{n\times n} diagonal matrix with \eqn{i}th diagonal element
+#'    \eqn{w_i=w(Z_i, \lambda)}. Here, \eqn{Z_i} is the \eqn{i}th row of an
+#'    \eqn{n \times q} nonstochastic auxiliary design matrix \eqn{Z}. Note:
+#'    \eqn{Z} as defined here does not have a column of ones, but is
+#'    concatenated to a column of ones when used in an auxiliary regression.
+#'    \eqn{\lambda} is a \eqn{q}-vector of unknown parameters, and
+#'    \eqn{w(\cdot)} is a real-valued, twice-differentiable function having the
+#'    property that there exists some \eqn{\lambda_0} for which
+#'    \eqn{w(Z_i,\lambda_0)=0} for all \eqn{i=1,2,\ldots,n}. Thus, the null
+#'    hypothesis of homoskedasticity may be expressed as
+#'    \eqn{\lambda=\lambda_0}.
 #'
-#' In the score test, the added term in the test statistic is of the
-#' form
-#' \deqn{\sum_{j=1}^{q} \left(\sum_{i=1}^{n} h_{ii} t_{ij}\right) \tau_j},
-#' where \eqn{t_{ij}} is the \eqn{(i,j)}th element of the Jacobian matrix
-#' \eqn{J} evaluated at \eqn{\lambda=\lambda_0}:
-#' \deqn{t_{ij}=\left.\frac{\partial w(Z_i, \lambda)}{\partial \lambda_j}\right|_{\lambda=\lambda_0}},
-#' and \eqn{\tau=(\bar{J}'\bar{J})^{-1}\bar{J}'d}, where \eqn{d} is the
-#' \eqn{n}-vector whose \eqn{i}th element is \eqn{e_i^2\bar{\sigma}^{-2}},
-#' \eqn{\bar{\sigma}^2=n^{-1}e'e}, and \eqn{\bar{J}=(I_n-1_n 1_n'/n)J}.
+#' In the score test, the added term in the test statistic is of the form
+#'    \deqn{\sum_{j=1}^{q} \left(\sum_{i=1}^{n} h_{ii} t_{ij}\right) \tau_j},
+#'    where \eqn{t_{ij}} is the \eqn{(i,j)}th element of the Jacobian matrix
+#'    \eqn{J} evaluated at \eqn{\lambda=\lambda_0}:
+#'    \deqn{t_{ij}=\left.\frac{\partial w(Z_i, \lambda)}{\partial \lambda_j}\right|_{\lambda=\lambda_0}},
+#'    and \eqn{\tau=(\bar{J}'\bar{J})^{-1}\bar{J}'d}, where \eqn{d} is the
+#'    \eqn{n}-vector whose \eqn{i}th element is \eqn{e_i^2\bar{\omega}^{-1}},
+#'    \eqn{\bar{\omega}=n^{-1}e'e}, and \eqn{\bar{J}=(I_n-1_n 1_n'/n)J}.
 #'
 #' @param method A character specifying which of the tests proposed in
 #'    \insertCite{Simonoff94;textual}{skedastic} to implement. \code{"mlr"}
@@ -159,8 +159,8 @@ simonoff_tsai <- function(mainlm, auxdesign = NA, method = c("mlr", "score"),
     tij <- sapply(1:q, function(j) vapply(1:n, function(i) J[i, j] -
                                             sum(J[, j]) / n, NA_real_), simplify = TRUE)
     Jbar <- (diag(n) - matrix(data = 1 / n, nrow = n, ncol = n)) %*% J
-    tau <- solve(crossprod(Jbar)) %*% t(Jbar) %*% d
-    h <- diag(X %*% solve(crossprod(X)) %*% t(X))
+    tau <- Rfast::spdinv(crossprod(Jbar)) %*% t(Jbar) %*% d
+    h <- diag(X %*% Rfast::spdinv(crossprod(X)) %*% t(X))
     addterm <- sum(vapply(1:q, function(j) sum(h * tij[, j]) * tau[j], NA_real_))
     teststat <- basestat + addterm
     if (statonly) return(teststat)
@@ -181,8 +181,9 @@ simonoff_tsai <- function(mainlm, auxdesign = NA, method = c("mlr", "score"),
       }
     } else stop("Invalid hetfun argument")
     ellp <- function(lambda) {
-      W <- diag(vapply(1:n, function(i) w(Z[i, ], lambda), NA_real_))
-      Winv <- solve(W)
+      Wdiag <- vapply(1:n, function(i) w(Z[i, ], lambda), NA_real_)
+      W <- diag(Wdiag)
+      Winv <- diag(1 / Wdiag)
       beta <- solve(t(X) %*% Winv %*% X) %*% t(X) %*% Winv %*% y
       sigmasq <- t(y - X %*% beta) %*% Winv %*% (y - X %*% beta) / n
       (- n / 2 * log(sigmasq) - 1 / 2 * sum(vapply(1:n, function(i)
@@ -216,7 +217,7 @@ simonoff_tsai <- function(mainlm, auxdesign = NA, method = c("mlr", "score"),
     L <- -2 * (ellp(lambda0) - MLE$value)
     w_at_MLE <- vapply(1:n, function(i) w(Z[i, ], MLE$par), NA_real_)
     Ghat <- diag(w_at_MLE / (prod(w_at_MLE ^ (1 / n))))
-    Xmhat <- pracma::sqrtm(solve(Ghat))$B %*% X
+    Xmhat <- pracma::sqrtm(Rfast::spdinv(Ghat))$B %*% X
     teststat <- as.double((n - p - 2) / n * L +
       log(det(crossprod(X)) / det(crossprod(Xmhat))))
     if (bartlett) {
